@@ -1,5 +1,6 @@
-from abstract_utilities.path_utils import path_join, mkdirs,get_file_create_time
+from abstract_utilities.path_utils import path_join, mkdirs,get_file_create_time,get_date
 from abstract_utilities.time_utils import get_time_stamp
+from abstract_utilities.read_write_utils import write_to_file
 from abstract_gui.simple_gui.gui_presets import get_browser
 import json
 import os
@@ -26,8 +27,8 @@ def save_response(js:dict, response:dict, title: str = str(get_time_stamp())):
             title = generated_text['title']
     except:
         print()
-    path = mkdirs(join_paths(mkdirs(path_join(mkdirs('response_data'), date())), js['model']))
-    pen(join_paths(path, title + '.json'), json.dumps(js))
+    path = mkdirs(path_join(mkdirs(path_join(mkdirs('response_data'), get_date())), js['model']))
+    write_to_file(file_path=join_paths(path, title + '.json'), contents=json.dumps(js))
     return generated_text
 
 
